Django Frontend Skeleton documentation — django-frontend-skeleton 3.0.0 documentation

### Navigation

- index
- next |
- django-frontend-skeleton 3.0.0 documentation »

# Django Frontend Skeleton documentation

Django Frontend Skeleton is a basic Django template skeleton built on HTML5 Boilerplate and Twitter Bootstrap.

With the convenience of an installable Django application, create custom templates built on top of one of the most well-known, widespread templates (HTML5 Boilerplate) and a robust front-end framework (Twitter Bootstrap.)

Version 2.0.0 of Django Frontend Skeleton is a much simpler package - it’s now just a small extended ‘skeleton’ template, which requires Django Frontend. No more duplication!

Package: | https://pypi.python.org/pypi/django-frontend-skeleton
Source: | https://github.com/jonfaustman/django-frontend-skeleton

## Starring

- HTML5 Boilerplate (based on 4.2.0)
- Modernizr (2.6.2)
- jQuery (1.10.2) and (2.0.3)
- Twitter Bootstrap (3.0.0)
- iOS-Orientationchange-Fix

## Getting Started

### Install

1. install django-frontend-skeleton (pip install, add to your requirements files, etc.)
2. add ‘djfrontend’ and ‘djfrontend.skeleton’ to your INSTALLED_APPS
3. make sure ‘django.contrib.staticfiles’ is also in your INSTALLED_APPS

### Extend

Extend the skeleton’s base template in your template(s)

    {% extends 'djfrontend/skeleton.html' %}

### Load

Load all the djfrontend tags if you want to add or change the template’s defaults.

    {% load djfrontend %}

## Template Blocks

Template blocks provided by Django Frontend which are fundamental for Django Frontend Skeleton.

### djfrontend_h5bp_css

Block to include {% djfrontend_normalize %} and/or {% djfrontend_h5bp_css %}.

### djfrontend_twbs_css

Block to override the included Twitter Bootstrap CSS and responsive CSS files.

### djfrontend_twbs_js

Override the included {% djfrontend_twbs_js %}.

## Further Documentation

For more documenation about Django Frontend read the documentation.

## Contents

- License
  - Component Specific Licenses
- Changelog
  - 3.0.0
  - 2.0.1
  - 2.0.0
  - 1.2.0
  - 1.1.1
  - 1.1.0
  - 1.0.0
  - 0.7.2
  - 0.7.1
  - 0.7.0
  - 0.6.0
  - 0.5.0
  - 0.4.0
  - 0.3.0
  - 0.2.0
  - 0.1.0

### Navigation

- index
- next |
- django-frontend-skeleton 3.0.0 documentation »